@@ -4,10 +4,6 @@ require_relative 'transmitter_wrapper'
 
 class Transmitter
 
-  def self.get_native_error
-    TransmitterWrapper.GetNativeError
-  end
-
   def self.send_command(message_byte_array, message_byte_array_len)
     message = FFI::MemoryPointer.new(:uchar, message_byte_array_len, true)
     message.put_array_of_uchar(0, message_byte_array)
@@ -26,26 +22,39 @@ class Transmitter
     end
   end
 
-  def self.activate_with_licence_file()
+  def self.activate_with_license_file()
     return activate()
   end
 
-  def self.activate_with_credentials(licenceKey)
-    return activate(licenceKey)
+  def self.activate_with_credentials(licenseKey)
+    return activate(licenseKey)
   end
 
-  def self.activate_with_credentials_and_proxy(licenceKey, proxyHost, proxyUserName, proxyPassword)
-    return activate(licenceKey, proxyHost, proxyUserName, proxyPassword)
+  def self.activate_with_credentials_and_proxy(licenseKey, proxyHost, proxyUserName, proxyPassword)
+    return activate(licenseKey, proxyHost, proxyUserName, proxyPassword)
   end
 
-  private_class_method def self.activate(licenceKey = "", proxyHost = "", proxyUserName = "", proxyUserPassword = "")
-    activation_result = TransmitterWrapper.Activate(licenceKey, proxyHost, proxyUserName, proxyUserPassword)
+  private_class_method def self.activate(licenseKey = "", proxyHost = "", proxyUserName = "", proxyUserPassword = "")
+    activation_result = TransmitterWrapper.Activate(licenseKey, proxyHost, proxyUserName, proxyUserPassword)
     if activation_result < 0
       error_message = get_native_error
-      raise Exception.new "Javonet activation result: " + activation_result.to_s + ". " + error_message
+      raise Exception.new "Javonet activation result: " + activation_result.to_s + ". Native error message: " + error_message
     else
       return activation_result
     end
   end
 
+  def self.get_native_error
+    TransmitterWrapper.GetNativeError
+  end
+
+  def self.set_config_source(configPath)
+    set_config_result = TransmitterWrapper.SetConfigSource(configPath)
+    if set_config_result < 0
+      error_message = get_native_error
+      raise Exception.new "Javonet set config source result: " + set_config_result.to_s + ". Native error message: " + error_message
+    else
+      return set_config_result
+    end
+  end
 end
