@@ -1,7 +1,6 @@
 package Javonet::Core::Receiver::Receiver;
 use strict;
 use warnings;
-use Exporter;
 use Config;
 use File::Basename;
 
@@ -16,23 +15,19 @@ BEGIN {
 
 use lib "$perlLibDirJavonet";
 use lib "$perlLibDirDeps";
-
 use aliased 'Javonet::Core::Interpreter::Interpreter' => 'Interpreter', qw(process);
 
-our @ISA = qw(Exporter);
-our @EXPORT = qw(send_command heart_beat);
-
 sub heart_beat {
-    my (@byte_array) = @_;
-    my $response = "10";
-    return $response;
+    my ($self, $message_byte_array_ref) = @_;
+    my @response_byte_array = (49, 48);
+    return \@response_byte_array;
 }
 
 sub send_command {
-    my ($byte_array_as_string) = @_;
-    my @byte_array = unpack("C*", Encode::encode("ascii", $byte_array_as_string));
-    my @response = Interpreter->process(\@byte_array);
-    return join '', map chr, @response;
+    my ($self, $message_byte_array_ref) = @_;
+    my @message_byte_array = @$message_byte_array_ref;
+    my @response_byte_array = Javonet::Core::Interpreter::Interpreter->process(\@message_byte_array);
+    return \@response_byte_array;
 }
 
 1;
