@@ -3,15 +3,11 @@ use strict;
 use warnings;
 use Cwd;
 use aliased 'Javonet::Core::Transmitter::PerlTransmitterWrapper' => 'PerlTransmitterWrapper' , qw(send_command_ activate_);
-use Exporter;
-
-our @ISA = qw(Exporter);
-our @EXPORT = qw(send_command activate_with_license_file activate_with_credentials activate_with_credentials_and_proxy);
 
 sub send_command {
-    my ($self, $message_ref) = @_;
-    my @response = PerlTransmitterWrapper->send_command($message_ref);
-    return @response;
+    my ($self, $message_byte_array_ref) = @_;
+    my $response_byte_array_ref = PerlTransmitterWrapper->send_command($message_byte_array_ref);
+    return $response_byte_array_ref;
 }
 
 sub activate_with_license_file {
