@@ -5,6 +5,9 @@ use lib 'lib';
 use FFI::Platypus;
 use Path::Tiny;
 use File::Spec;
+use Config;
+use POSIX qw(uname);
+
 my $ffi;
 
 my $send_command_native;
@@ -21,14 +24,17 @@ sub initialize {
         my $dir = File::Spec->rel2abs(__FILE__);
         my $current_dir = path($dir)->parent(3);
         my $perl_native_lib;
+
+        my $arch = (uname())[4] =~ /64/ ? "X64" : "X86";
+
         if ($osname eq "linux") {
-            $perl_native_lib = 'Binaries/Native/Linux/X64/libJavonetPerlRuntimeNative.so';
+            $perl_native_lib = "Binaries/Native/Linux/$arch/libJavonetPerlRuntimeNative.so";
         }
         elsif ($osname eq "darwin") {
-            $perl_native_lib = 'Binaries/Native/MacOs/X64/libJavonetPerlRuntimeNative.dylib';
+            $perl_native_lib = "Binaries/Native/MacOs/$arch/libJavonetPerlRuntimeNative.dylib";
         }
         else {
-            $perl_native_lib = 'Binaries/Native/Windows/X64/JavonetPerlRuntimeNative.dll';
+            $perl_native_lib = "Binaries/Native/Windows/$arch/JavonetPerlRuntimeNative.dll";
         }
         $ffi->lib("$current_dir/$perl_native_lib");
         $send_command_native = $ffi->function('SendCommand' => [ 'uchar[]', 'int' ] => 'int');
@@ -85,4 +91,4 @@ sub set_config_source {
     }
 }
 
-1;
+1;
\ No newline at end of file
